======================================================
oslo.service -- Library for running OpenStack services
======================================================

oslo.service provides a framework for defining new long-running
services using the patterns established by other OpenStack
applications. It also includes utilities long-running applications
might need for working with SSL or WSGI, performing periodic
operations, interacting with systemd, etc.

Contents
========

.. toctree::
   :maxdepth: 2

   install/index
   user/index
   configuration/index
   reference/index
   contributor/index


Release Notes
=============

Read also the `oslo.service Release Notes
<https://docs.openstack.org/releasenotes/oslo.service/>`_.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
